#
# spec file for package libqt5-qttools
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt5_snapshot 1
%define base_name libqt5
%define real_version 5.15.12
%define so_version 5.15.12
%define tar_version qttools-everywhere-src-%{version}
%if 0%{?suse_version} >= 1330
%bcond_without qdoc
%else
# Needs clang >= 3.9.0
%bcond_with qdoc
%endif
Name:           libqt5-qttools
Version:        5.15.12+kde4
Release:        150600.1.6
Summary:        Qt 5 QtTools Module
# Legal:
# most src/ subfolders are GPL-3.0-only WITH Qt-GPL-exception-1.0, except:
# qtpaths is BSD-3-Clause
# qdoc is GPL-3.0-only WITH Qt-GPL-exception-1.0 + (LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)) == GPL-3.0-only
# src/shared contains BSD-3-Clause and LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later) files. The
# 'GPL-3.0-only WITH Qt-GPL-exception-1.0' files in this folder are only used on Windows.
License:        (LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)) AND GPL-3.0-only WITH Qt-GPL-exception-1.0
Group:          Development/Libraries/X11
URL:            https://www.qt.io
Source:         %{tar_version}.tar.xz
Source1:        baselibs.conf
Source11:       designer5.desktop
Source12:       linguist5.desktop
Source13:       assistant5.desktop
Source14:       qdbusviewer5.desktop
Source99:       libqt5-qttools-rpmlintrc
%if %{with qdoc}
BuildRequires:  clang-devel >= 3.9.0
%endif
BuildRequires:  fdupes
BuildRequires:  libqt5-qtbase-devel >= %{real_version}
BuildRequires:  libqt5-qtbase-private-headers-devel >= %{real_version}
BuildRequires:  libqt5-qtdeclarative-private-headers-devel >= %{real_version}
BuildRequires:  libxslt-devel
%if %{qt5_snapshot}
#to create the forwarding headers
BuildRequires:  perl
%endif
BuildRequires:  update-desktop-files
BuildRequires:  xz
Requires:       %{name}-qhelpgenerator = %{version}
# help files are SQLite databases, so assistant/qhelpgenerator need the SQLite plugin
Requires:       libQt5Sql5-sqlite >= %{real_version}
Requires:       libqt5-qdbus = %{version}
Requires:       libqt5-qtpaths = %{version}
%requires_ge    libQt5DBus5
Recommends:     libqt5-linguist
Recommends:     libqt5-qtdoc-qch >= %{version}

%description
The QtTools modules contains some tools mostly useful for application development.

Included are QtAssistant (help browser), QtDesigner (GUI design), QDbusViewer
and several more.

%prep
%autosetup -p1 -n %{tar_version}

%package devel
Summary:        Development files for the Qt5 Tools library
Group:          Development/Libraries/X11
Requires:       %{name}-qhelpgenerator = %{version}
Requires:       libQt5Designer5 = %{version}
Requires:       libQt5DesignerComponents5 = %{version}
Requires:       libQt5Help5 = %{version}
Requires:       libqt5-linguist-devel = %{version}
Requires:       libxslt-devel
Requires:       pkgconfig(Qt5Xml) >= %{real_version}
Recommends:     %{name} = %{version}
Recommends:     %{name}-doc = %{version}

%description devel
You need this package if you want to compile programs with qttools.

%package private-headers-devel
Summary:        Non-ABI stable experimental API for the Qt5 Tools library
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}
BuildArch:      noarch

%description private-headers-devel
This package provides private headers of libqt5-qttools that are normally
not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%package examples
Summary:        Qt5 tools examples
Group:          Development/Libraries/X11
License:        BSD-3-Clause
Recommends:     %{name}-devel

%description examples
Examples for the libqt5-qttools module.

%package example-plugins
Summary:        Example plugins for Qt5 Designer
Group:          Development/Libraries/X11
License:        BSD-3-Clause
Recommends:     %{name}-examples

%description example-plugins
Example plugins for Qt5 Designer, e.g. a TicTacToe and a World Clock widget.

%package -n libQt5Designer5
Summary:        Qt 5 Designer Library
Group:          Development/Libraries/X11
License:        GPL-3.0-only WITH Qt-GPL-exception-1.0
%requires_ge    libQt5Widgets5
%requires_ge    libQt5Xml5

%description -n libQt5Designer5
The Qt 5 Designer library.

%package -n libQt5DesignerComponents5
Summary:        Qt 5 Designer Components Library
Group:          Development/Libraries/X11
License:        GPL-3.0-only WITH Qt-GPL-exception-1.0
Requires:       libQt5Designer5 = %{version}

%description -n libQt5DesignerComponents5
The Qt 5 Designer Components library.

%package -n libQt5Help5
Summary:        Qt 5 Help Library
Group:          Development/Libraries/X11
%requires_ge    libQt5Network5
%requires_ge    libQt5Sql5
%requires_ge    libQt5Widgets5

%description -n libQt5Help5
The Qt 5 Help library.

%package qhelpgenerator
Summary:        Generator for Qt5 Help files (qch)
Group:          Development/Libraries/X11
# help files are SQLite databases, so assistant/qhelpgenerator need the SQLite plugin
Requires:       libQt5Sql5-sqlite >= %{real_version}

%description qhelpgenerator
Binaries for generating .qch help catalogs.

%package -n libqt5-linguist
Summary:        Qt 5 Linguist Tools
Group:          Development/Libraries/X11
License:        GPL-3.0-only WITH Qt-GPL-exception-1.0
%requires_ge    libQt5PrintSupport5
%requires_ge    libQt5Widgets5
%requires_ge    libQt5Xml5

%description -n libqt5-linguist
The Qt 5 Linguist Tools.

%package -n libqt5-linguist-devel
Summary:        Development files for the Qt 5 Linguist tools
Group:          Development/Libraries/X11
Requires:       libqt5-linguist = %{version}
Requires:       pkgconfig(Qt5Core) >= %{real_version}

%description -n libqt5-linguist-devel
The Qt 5 Linguist Tools - development files.

%package -n libqt5-qdbus
Summary:        Command line client for communication over D-Bus
Group:          Development/Libraries/X11
License:        GPL-3.0-only WITH Qt-GPL-exception-1.0
Conflicts:      %{name} < %{version}

%description -n libqt5-qdbus
Command line client for communication over D-Bus.

%package -n libqt5-qtpaths
Summary:        Command line client to QStandardPaths
Group:          Development/Libraries/X11
License:        BSD-3-Clause
Conflicts:      %{name} < %{version}

%description -n libqt5-qtpaths
Command line client to QStandardPaths.

%package doc
Summary:        Qt 5 tool used by Qt Developers to generate documentation
Group:          Development/Libraries/C and C++
License:        GPL-3.0-only
Provides:       libqt5-qtbase-doc = %{version}
Obsoletes:      libqt5-qtbase-doc < %{version}
# qdoc hardcodes clang include paths: boo#1109367, QTBUG-70687
%global _clang_major_version %(printf %{pkg_version clang-devel} | cut -d. -f1)

%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150200
%requires_eq libclang%{_clang_major_version}
%else
%requires_eq clang%{_clang_major_version}
%endif

%description doc
Qt 5 tool used by Qt Developers to generate documentation for software projects.

%post -p /sbin/ldconfig
%post -n libQt5Designer5 -p /sbin/ldconfig
%post -n libQt5DesignerComponents5 -p /sbin/ldconfig
%post -n libQt5Help5 -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%postun -n libQt5Designer5 -p /sbin/ldconfig
%postun -n libQt5DesignerComponents5 -p /sbin/ldconfig
%postun -n libQt5Help5 -p /sbin/ldconfig

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
%if %{qt5_snapshot}
#force the configure script to generate the forwarding headers (it checks whether .git directory exists)
mkdir .git
%endif
%qmake5
%make_jobs

%install
%qmake5_install
find %{buildroot}%{_libdir} -type f -name '*pc' -print -exec sed -i -e "s, -L%{buildroot}/?\S+,,g" -e "s,^moc_location=.*,moc_location=%{_libqt5_bindir}/moc," -e "s,uic_location=.*,uic_location=%{_libqt5_bindir}/uic," {} +
%fdupes -s %{buildroot}%{_libqt5_includedir}

# kill .la files
find %{buildroot}%{_libdir} -type f -name "*.la" -delete -print

# Link all the binaries with -qt5 suffix to %%{_bindir}
mkdir -p %{buildroot}%{_bindir}
pushd %{buildroot}%{_libqt5_bindir}
for i in * ; do
  case "${i}" in
   assistant|designer|lconvert|linguist|lrelease|lupdate|pixeltool|qcollectiongenerator|qdbus|qdbusviewer|qdoc|qhelpgenerator)
      ln -s %{_libqt5_bindir}/$i %{buildroot}%{_bindir}/${i}-qt5
      ;;
   *)
      # No conflict with Qt4, so keep the original name for compatibility
      ln -s %{_libqt5_bindir}/$i %{buildroot}%{_bindir}/${i}
      ln -s %{_libqt5_bindir}/$i %{buildroot}%{_bindir}/${i}-qt5
      ;;
  esac
done
popd

# Do not add dependencies on the implementation of the abstract Designer plugin
# interface provided by the plugins, QTCREATORBUG-22886
rm %{buildroot}%{_libqt5_libdir}/cmake/Qt5Designer/Qt5Designer_*Plugin.cmake

install -D -m644 %{SOURCE11} %{buildroot}%{_datadir}/applications/designer5.desktop
install -D -m644 %{SOURCE12} %{buildroot}%{_datadir}/applications/linguist5.desktop
install -D -m644 %{SOURCE13} %{buildroot}%{_datadir}/applications/assistant5.desktop
install -D -m644 %{SOURCE14} %{buildroot}%{_datadir}/applications/qdbusviewer5.desktop

install -D -m644 src/assistant/assistant/images/assistant.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/assistant5.png
install -D -m644 src/assistant/assistant/images/assistant-128.png %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/assistant5.png
install -D -m644 src/linguist/linguist/images/icons/linguist-32-32.png %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/linguist5.png
install -D -m644 src/linguist/linguist/images/icons/linguist-128-32.png %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/linguist5.png
install -D -m644 src/designer/src/designer/images/designer.png %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/designer5.png
install -D -m644 src/qdbus/qdbusviewer/images/qdbusviewer.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/qdbusviewer5.png
install -D -m644 src/qdbus/qdbusviewer/images/qdbusviewer-128.png %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/qdbusviewer5.png

%files
%license LICENSE.*
%{_bindir}/assistant*
%{_bindir}/designer*
%{_bindir}/pixeltool*
%{_bindir}/qdbusviewer*
%{_bindir}/qtdiag*
%{_bindir}/qtplugininfo*
%{_bindir}/qtattributionsscanner*
%{_bindir}/qdistancefieldgenerator*
%{_libqt5_bindir}/assistant*
%{_libqt5_bindir}/designer*
%{_libqt5_bindir}/pixeltool*
%{_libqt5_bindir}/qdbusviewer*
%{_libqt5_bindir}/qtdiag*
%{_libqt5_bindir}/qtplugininfo*
%{_libqt5_bindir}/qtattributionsscanner*
%{_libqt5_bindir}/qdistancefieldgenerator
%{_datadir}/applications/assistant5.desktop
%{_datadir}/applications/designer5.desktop
%{_datadir}/applications/qdbusviewer5.desktop
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/*
%dir %{_datadir}/icons/hicolor/*/apps
%{_datadir}/icons/hicolor/*/apps/assistant5.png
%{_datadir}/icons/hicolor/*/apps/designer5.png
%{_datadir}/icons/hicolor/*/apps/qdbusviewer5.png
%dir %{_libqt5_libdir}/qt5/plugins/designer
%{_libqt5_libdir}/qt5/plugins/designer/libqquickwidget.so
# CMake target for some of the binaries in this package. Own the dir to not require CMake
%dir %{_libqt5_libdir}/cmake/
%{_libqt5_libdir}/cmake/Qt5AttributionsScannerTools/

%files -n libqt5-linguist
%license LICENSE.*
%{_bindir}/lconvert*
%{_bindir}/linguist*
%{_bindir}/lprodump*
%{_bindir}/lrelease*
%{_bindir}/lupdate*
%{_libqt5_bindir}/lconvert*
%{_libqt5_bindir}/linguist*
%{_libqt5_bindir}/lprodump*
%{_libqt5_bindir}/lrelease*
%{_libqt5_bindir}/lupdate*
%{_datadir}/applications/linguist5.desktop
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/*
%dir %{_datadir}/icons/hicolor/*/apps
%{_datadir}/icons/hicolor/*/apps/linguist5.png

%files -n libQt5Designer5
%license LICENSE.*
%{_libqt5_libdir}/libQt5Designer.so.*

%files -n libQt5DesignerComponents5
%license LICENSE.*
%{_libqt5_libdir}/libQt5DesignerComponents.so.*

%files -n libQt5Help5
%license LICENSE.*
%{_libqt5_libdir}/libQt5Help.so.*

%files -n libqt5-linguist-devel
%license LICENSE.*
%{_libqt5_libdir}/cmake/Qt5LinguistTools/
%{_datadir}/qt5/phrasebooks

%files -n libqt5-qdbus
%license LICENSE.*
%{_bindir}/qdbus-qt5
%{_libqt5_bindir}/qdbus

%files -n libqt5-qtpaths
%license LICENSE.*
%{_bindir}/qtpaths*
%{_libqt5_bindir}/qtpaths

%if %{with qdoc}
%files doc
%license LICENSE.*
%{_bindir}/qdoc*
%{_libqt5_bindir}/qdoc*
# CMake target for some of the binaries in this package. Own the dir to not require CMake
%dir %{_libqt5_libdir}/cmake/
%{_libqt5_libdir}/cmake/Qt5DocTools/
%endif

%files qhelpgenerator
%license LICENSE.*
%{_bindir}/qhelpgenerator*
%{_bindir}/qcollectiongenerator*
%{_libqt5_bindir}/qhelpgenerator*
%{_libqt5_bindir}/qcollectiongenerator*

%files private-headers-devel
%license LICENSE.*
%{_libqt5_includedir}/QtDesigner/%{so_version}
%{_libqt5_includedir}/QtDesignerComponents/%{so_version}
%{_libqt5_includedir}/QtHelp/%{so_version}
%{_libqt5_includedir}/QtUiTools/%{so_version}

%files devel
%license LICENSE.*
%exclude %{_libqt5_includedir}/QtDesigner/%{so_version}
%{_libqt5_includedir}/QtDesigner
%exclude %{_libqt5_includedir}/QtDesignerComponents/%{so_version}
%{_libqt5_includedir}/QtDesignerComponents
%exclude %{_libqt5_includedir}/QtHelp/%{so_version}
%{_libqt5_includedir}/QtHelp
%exclude %{_libqt5_includedir}/QtUiTools/%{so_version}
%{_libqt5_includedir}/QtUiTools
%{_libqt5_includedir}/QtUiPlugin
%{_libqt5_libdir}/cmake/Qt5Designer/
%{_libqt5_libdir}/cmake/Qt5DesignerComponents/
%{_libqt5_libdir}/cmake/Qt5Help/
%{_libqt5_libdir}/cmake/Qt5UiTools/
%{_libqt5_libdir}/cmake/Qt5UiPlugin/
%{_libqt5_libdir}/libQt5*.prl
%{_libqt5_libdir}/libQt5*.so
%{_libqt5_libdir}/libQt5*.a
%{_libqt5_libdir}/pkgconfig/Qt5*.pc
%{_libqt5_archdatadir}/mkspecs/modules/qt_lib_*.pri
%dir %{_datadir}/qt5

%files examples
%license LICENSE.*
%{_libqt5_examplesdir}/

%files example-plugins
%license LICENSE.*
%{_libqt5_libdir}/qt5/plugins/designer
%exclude %{_libqt5_libdir}/qt5/plugins/designer/libqquickwidget.so

%changelog
* Fri Dec 29 2023 fabian@ritter-vogt.de
- Update to version 5.15.12+kde4, rebased upstream:
  * qdoc: Ensure the generated temporary header file is closed properly
  * Bump version to 5.15.12
* Fri Oct  6 2023 fabian@ritter-vogt.de
- Update to version 5.15.11+kde3, rebased upstream:
  * qtattributionsscanner: Support multiple license files
  * macdeployqt: Ignore repeated references to binary when parsing otool -L
  * Build QtDesigner plugins in all configurations
  * lupdate: Allow multiple specifiers after method signature
* Tue Jun 13 2023 fabian@ritter-vogt.de
- Update to version 5.15.10+kde3, rebased upstream:
  * CMake: Fix qt5_create_translation for same-named .ts files
  * Drop superfluous network dependency from assistant/{help,qhelpgenerator}.pro
  * qdoc: Do not split module names in different tags
  * qdoc: Do not generate tags from titles anymore
  * Skip endonym in linguist settings list when not available
  * lrelease-pro: Take EXTRA_TRANSLATIONS into account
* Fri Apr 21 2023 fabian@ritter-vogt.de
- Update to version 5.15.8+kde10, rebased upstream:
  * qdoc: Fix assert on empty link target
  * macdeployqt: don’t err on unexpected otool output
  * Don't run qdoc tests if qdoc was not enabled during configure
  * CMake: Fix qt_create_translation to not remove .ts files on "clean"
  * lupdate: Support numeric literal separators
  * designer: Fix MSVC warning about returning address of local variable or temporary
  * Bump copyright year to 2022
* Mon Jan  9 2023 fabian@ritter-vogt.de
- Update to version 5.15.8+kde1, rebased upstream:
  * qdoc: Add styling for note, important and warning
  * macdeployqt: don’t stop qmlimportscanner after 30s
* Thu Nov  3 2022 fabian@ritter-vogt.de
- Update to version 5.15.7+kde1, rebased upstream:
  * qdoc: Fix warnings about generatelist arguments
  * qdoc: Fix Section::reduce() omitting sections with obsolete members
  * macdeployqt: detect debug libs by using “_debug” suffix
  * Fix extensions without leading period having first character dropped
  * Doc: Remove mention of custom filters, part 2
* Mon Sep 26 2022 fabian@ritter-vogt.de
- Update to version 5.15.6+kde1, rebased upstream:
  * windeployqt: Account for debug version of ICU library when deploying
  * Doc: Fix a typo in the "Introduction to QDoc" documentation page
  * Doc: Remove mention of custom filters
  * Examples: Don't use QDir::separator() in internal paths
  * Assistant: Make QResultWidget linkColor stylable
* Mon Jun 27 2022 fabian@ritter-vogt.de
- Update to version 5.15.5+kde1, rebased upstream:
  * Ensure FileAttributeSetTable is filled ordered so we get the same qch file each time
  * Fix regression in lconvert handling empty translations
  * Qt Designer: Fix alignment when adding new QTableWidget columns
  * Qt Designer: Fix alignment of horizontal QTableWidget headers
  * Qt Designer: Fix saving of item view header visibility on page based containers
  * Qt Designer: Slow down wheel scrolling of the widget box
  * Revert "Update commercial license headers"
  * QDoc: Fix possible crash in WebXMLGenerator
  * Fix check for malformed input when decoding translations
  * Fix redeclared variable name
  * qdoc: Allow any type of page as qhp indexTitle
  * qdoc: Don't clear the warning count in single-exec mode
  * Bump copyright year to 2021
  * qdoc: Fix generation of TOC for basic QML/JS types
  * Update commercial license headers
  * qdoc: Fix addendums for QML signals that contain '.' in the name
  * qdoc: Ignore empty example meta tags
  * qdoc: Fix breadcrumb generation for normal page nodes
- Drop 0001-Revert-Bump-version.patch, it's versioned correctly now
* Tue Jun 22 2021 fabian@ritter-vogt.de
- Switch to KDE's maintenance branch
- Update to version 5.15.2+kde17:
  * Clamp registered collection time-stamp to SOURCE_DATE_EPOCH if set
  * CMake: Fix handling of -extensions argument
  * Add changes file for Qt 5.12.10
  * Fix qdbusviewer.exe missing version and copyright information
  * qdoc: Avoid excess warnings for undocumented namespaces
  * qdoc: Skip ignored entries in .qhp
  * qdoc: DocBook generator: Fix \headerfile generation
  * Replace prefined application name by a generic name
  * Doc: Document attribution argument
  * qdoc: Handle JSON as plain text
  * CMake: Fix usage of qt_create_translation in a CTest
  * Clear out deprecated QLocale::Language values
  * qt5_create_translation: Fix handling of directory dependencies
  * Add changes file for Qt 5.15.2
  * qdoc: Avoid duplicates in \sincelist
  * qtpaths: Add missing location types
  * Bump version
- Add patch to reset version to 5.15.2:
  * 0001-Revert-Bump-version.patch
* Fri Nov 20 2020 fabian@ritter-vogt.de
- Update to 5.15.2:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qttools.git/plain/dist/changes-5.15.2/?h=5.15.2
* Mon Sep 28 2020 christophe@krop.fr
- Fix the clang requirement for Leap 15.2. The clang headers are
  also in the libclang<major version> package.
- Use the %%pkg_version macro available since Leap 15
* Thu Sep 10 2020 fabian@ritter-vogt.de
- Update to 5.15.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qttools.git/plain/dist/changes-5.15.1/?h=5.15.1
* Mon Aug  3 2020 normand@linux.vnet.ibm.com
- Add _constraints with 4GB min disk space
* Tue May 26 2020 callumjfarmer13@gmail.com
- Update to version 5.15.0:
  * No changelog available
* Wed May 20 2020 callumjfarmer13@gmail.com
- Update to version 5.15.0-rc2:
  * No changelog available
* Wed May  6 2020 fabian@ritter-vogt.de
- Update to 5.15.0-rc:
  * New bugfix release
  * For the changes between 5.14.2 and 5.15.0 please see:
    http://code.qt.io/cgit/qt/qttools.git/plain/dist/changes-5.15.0/?h=5.15.0
* Fri Apr 24 2020 fabian@ritter-vogt.de
- Update to 5.15.0-beta4:
  * New bugfix release
  * No changelog available
* Tue Apr 14 2020 fabian@ritter-vogt.de
- Update to 5.15.0-beta3:
  * New bugfix release
  * No changelog available
* Tue Mar 24 2020 fabian@ritter-vogt.de
- Update to 5.15.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Feb 28 2020 fabian@ritter-vogt.de
- Update to 5.15.0-beta1:
  * New bugfix release
  * No changelog available
* Wed Feb 19 2020 fabian@ritter-vogt.de
- Update to 5.15.0-alpha:
  * New feature release
  * For more details please see:
    https://wiki.qt.io/New_Features_in_Qt_5.15
* Mon Jan 27 2020 fabian@ritter-vogt.de
- Update to 5.14.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qttools.git/plain/dist/changes-5.14.1/?h=v5.14.1
* Mon Dec 16 2019 christophe@krop.fr
- Update the license tags.
* Thu Dec 12 2019 fabian@ritter-vogt.de
- Update to 5.14.0:
  * New bugfix release
  * For the changes between 5.13.2 and 5.14.0 please see:
    https://code.qt.io/cgit/qt/qttools.git/tree/dist/changes-5.14.0?h=v5.14.0
  * For the changes between 5.13.1 and 5.13.2 please see:
    https://code.qt.io/cgit/qt/qttools.git/tree/dist/changes-5.13.2?h=v5.14.0
* Wed Dec  4 2019 fabian@ritter-vogt.de
- Update to 5.14.0-rc:
  * New bugfix release
  * No changelog available
  * For more details please see:
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
* Tue Nov 12 2019 fabian@ritter-vogt.de
- Update to 5.14.0-beta3:
  * New bugfix release
  * No changelog available
* Thu Oct 24 2019 fabian@ritter-vogt.de
- Update to 5.14.0-beta2:
  * New bugfix release
  * No changelog available
* Tue Oct 15 2019 fabian@ritter-vogt.de
- Update to 5.14.0-beta1:
  * New bugfix release
  * No changelog available
* Mon Sep 30 2019 fabian@ritter-vogt.de
- Update to 5.14.0-alpha:
  * New feature release
  * No changelog available
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
* Fri Sep  6 2019 fabian@ritter-vogt.de
- Update to 5.13.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qttools.git/plain/dist/changes-5.13.1/?h=v5.13.1
* Tue Sep  3 2019 fabian@ritter-vogt.de
- Split qcollectiongenerator and qhelpgenerator into a subpackage
  which is required by the Qt5Help cmake module
* Thu Aug 29 2019 stefan.bruens@rwth-aachen.de
- Remove the accidental dependency from the devel package on the
  Qt Designer example plugins, referenced in the cmake files.
- Move the example plugins to a separate subpackage.
* Thu Aug 29 2019 christophe@krop.fr
- Require libqt5-qttools again. This is causing multiple build issues.
- Clean the spec file.
* Thu Aug 29 2019 stefan.bruens@rwth-aachen.de
- Drop some not unnecessary library runtime Requires: libQt5Designer5,
  libQt5DesignerComponents5, libQt5Help5, pulled in automatically.
- Change libqt5-qttools and libqt5-qttools-doc Requires in devel
  subpackage to Recommends, as the tools are not required for building.
- Make some Summaries and Descriptions more useful.
- Correct requires for matching Clang headers, the headers are part
  of the libclang package for current Clang versions
* Tue Jul  2 2019 fabian@ritter-vogt.de
- Link from Qt bindir into %%_bindir, not the other way around to fix
  applicationDirPath called from Qt binaries
- Add -qt5 suffix to all binaries in %%_bindir
- Drop add-qt5-suffix.patch, no longer necessary
* Mon Jul  1 2019 fabian@ritter-vogt.de
- Merge fix-for-opensuse-lrelease-qt5.patch and
  fix-for-opensuse-qmake-qt5.patch into add-qt5-suffix.patch
* Mon Jul  1 2019 jslaby@suse.com
- add fix-for-opensuse-lrelease-qt5.patch
  Fixes build of other projects as our lrelease is called lrelease-qt5.
* Wed Jun 19 2019 fabian@ritter-vogt.de
- Update to 5.13.0:
  * New bugfix release
  * No changelog available
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qttools.git/plain/dist/changes-5.13.0/?h=5.13
- Drop patches, now upstream:
  * 0001-qdoc-Don-t-spam-garbage.patch
* Wed Jun  5 2019 fabian@ritter-vogt.de
- Add patch to fix doc builds getting terminated:
  * 0001-qdoc-Don-t-spam-garbage.patch
* Tue Jun  4 2019 fabian@ritter-vogt.de
- Update to 5.13.0-rc:
  * New bugfix release
  * No changelog available
* Tue May 28 2019 mliska@suse.cz
- Use -ffat-lto-objects in order to provide proper static library:
  libQt5UiTools.a.
* Mon Apr 29 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta2:
  * New bugfix release
  * No changelog available
* Thu Apr 18 2019 fabian@ritter-vogt.de
- Update to 5.12.3:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qttools.git/plain/dist/changes-5.12.3/?h=v5.12.3
* Thu Mar 21 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta1:
  * New feature release
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qttools.git/plain/dist/changes-5.13.0/?h=5.13
- Refresh fix-for-opensuse-qmake-qt5.patch
* Thu Mar 14 2019 fabian@ritter-vogt.de
- Update to 5.12.2:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qttools.git/plain/dist/changes-5.12.2/?h=5.12.2
* Fri Feb  1 2019 fabian@ritter-vogt.de
- Update to 5.12.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qttools.git/plain/dist/changes-5.12.1/?h=v5.12.1
  * qcollectiongenerator got reintroduced as wrapper for qhelpgenerator
* Thu Dec  6 2018 fabian@ritter-vogt.de
- Update to 5.12.0:
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qttools.git/plain/dist/changes-5.12.0/?h=v5.12.0
* Mon Dec  3 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc2:
  * New bugfix release
  * Only important bugfixes
- Changelog for Qt 5.12.0:
  * http://code.qt.io/cgit/qt/qttools.git/plain/dist/changes-5.12.0/?h=5.12.0
* Thu Nov 22 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc:
  * New bugfix release
  * No changelog available
* Thu Nov  8 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta4:
  * New bugfix release
  * No changelog available
* Fri Oct 26 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta3:
  * New bugfix release
  * No changelog available
* Wed Oct 17 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta1:
  * New bugfix release
  * No changelog available
* Tue Oct  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0-alpha:
  * New feature release
  * For more details please see:
  * http://wiki.qt.io/New_Features_in_Qt_5.12
  * qhelpconverter got removed
  * qcollectiongenerator got merged into qhelpgenerator
* Fri Sep 21 2018 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qttools.git/plain/dist/changes-5.11.2/?h=v5.11.2
- Add requires_eq for clang to workaround QTBUG-70687 (boo#1109367)
- Use %%license, remove %%defattr
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qttools.git/plain/dist/changes-5.11.1/?h=v5.11.1
* Tue May 22 2018 fabian@ritter-vogt.de
- Update to 5.11.0
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qttools.git/plain/dist/changes-5.11.0/?h=v5.11.0
- Drop revert-static-libclang.patch
* Tue May  8 2018 fabian@ritter-vogt.de
- Update to 5.11.0-rc
  * New bugfix release
  * No changelog available
- Add patch to support dynamic linking against LLVM and clang again:
  * revert-static-libclang.patch
- Convert to patch -p1 format:
  * fix-for-opensuse-qmake-qt5.patch
* Mon Apr 23 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta4
  * New bugfix release
  * No changelog available
* Wed Apr 11 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta3
  * New bugfix release
  * No changelog available
* Wed Mar 28 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta2
  * New bugfix release
  * No changelog available
* Tue Mar 13 2018 christophe@krop.fr
- Fix the license tag.
* Thu Mar  1 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta1
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qttools.git/plain/dist/changes-5.11.0-beta1/?h=v5.11.0-beta1
* Tue Feb 20 2018 fabian@ritter-vogt.de
- Update to 5.11.0-alpha
  * New feature release
  * For more details please see:
  * https://wiki.qt.io/New_Features_in_Qt_5.11
  * qdoc needs clang which is not available on 42.x.
  Don't require it there.
* Wed Feb 14 2018 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qttools.git/plain/dist/changes-5.10.1/?h=v5.10.1
* Fri Dec  8 2017 christophe@krop.fr
- Update the license tag (boo#967696)
* Thu Dec  7 2017 fabian@ritter-vogt.de
- Update to 5.10.0 final
  * New bugfix release
* Sun Dec  3 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 2
  * New bugfix release
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 1
  * New bugfix release
* Sat Nov 25 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details, see:
    http://code.qt.io/cgit/qt/qttools.git/tree/dist/changes-5.9.3/?h=v5.9.3
* Mon Nov 20 2017 tittiatcoke@gmail.com
- Recommend to install the Qt Help files in QCH format
  to make Qt Assistent usable
* Wed Nov 15 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 4
- Contains bugfixes
* Thu Nov  2 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 3
- Contains bugfixes
* Mon Oct 30 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 2
- Contains bugfixes
* Mon Oct  9 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 1
- For more information visit:
    https://blog.qt.io/blog/2017/10/09/qt-5-10-beta-released/
* Sun Oct  8 2017 lbeltrame@kde.org
- Update to 5.9.2
  * For more details please see:
    https://blog.qt.io/blog/2017/10/06/qt-5-9-2-released/
* Mon Sep 25 2017 fabian@ritter-vogt.de
- Update to 5.10 Alpha 1
- For more information visit:
    https://blog.qt.io/blog/2017/09/13/qt-5-10-alpha-released/
* Mon Sep 11 2017 jengelh@inai.de
- Update descriptions.
- Use find -exec's "+" strategy.
* Sat Jul  1 2017 lbeltrame@kde.org
- Update to 5.9.1
  * For more details please see:
    http://blog.qt.io/blog/2017/06/30/qt-5-9-1-released/
* Wed May 31 2017 fabian@ritter-vogt.de
- Update to 5.9.0 final
* Wed May 24 2017 fabian@ritter-vogt.de
- Update to 5.9.0 RC:
  * For more details please see:
    http://lists.qt-project.org/pipermail/announce/2017-May/000115.html
    and https://wiki.qt.io/New_Features_in_Qt_5.9
- Qt5CLucene5 dropped upstream
* Wed Dec 14 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * For more details please see:
    https://blog.qt.io/blog/2016/12/14/qt-5-7-1-released/
    and https://www.qt.io/qt5-7/
* Sat Sep 24 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * For more details please see:
    https://www.qt.io/qt5-7/
* Wed Jun  8 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * For more details please see:
    http://blog.qt.io/blog/2016/06/08/qt-5-6-1-released/
* Fri Mar 18 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    http://blog.qt.io/blog/2016/03/16/qt-5-6-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.6
* Fri Oct 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1
  * For more details please see:
    http://blog.qt.io/blog/2015/10/15/qt-5-5-1-released/
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * For more details please see:
    http://blog.qt.io/blog/2015/07/01/qt-5-5-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.5
- Drop qdbusviewer-restore-the-window-size-and-state-on-startup.patch
  and change-creation-date-to-a-fixed-date.patch, merged upstream
* Wed Jun  3 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2
  * Bugfix release, for more details please see:
    http://blog.qt.io/blog/2015/06/02/qt-5-4-2-released/
* Tue Feb 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1
  * For more details please see:
    http://blog.qt.io/blog/2015/02/24/qt-5-4-1-released/
- Add minimal requires on other Qt5 libraries, as well the one from
  this source package
- Added libqt5-qttools-rpmlintrc due to shlib-fixed-dependency
* Fri Feb 20 2015 buschmann23@opensuse.org
- added libQt5Sql5-sqlite to the Requires for libqt5-qttools, because
  qhelpgenerator needs it to work, what is not automatically recognized by rpm
* Thu Feb 19 2015 hrvoje.senjan@gmail.com
- Add qdbusviewer-restore-the-window-size-and-state-on-startup.patch
  and change-creation-date-to-a-fixed-date.patch
* Mon Jan 12 2015 liujianfeng1994@gmail.com
- Add fix-for-opensuse-qmake-qt5.patch
  * Fix lupdate can't find qmake configuration file default (rh#1009893)
* Wed Dec 10 2014 hrvoje.senjan@gmail.com
- Update to 5.4 Final
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/12/10/qt-5-4-released/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
* Thu Nov 27 2014 hrvoje.senjan@gmail.com
- Update to 5.4 RC
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/11/27/qt-5-4-release-candidate-available/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
- Make linguist and main subpackages also own hicolor directory
* Tue Sep 16 2014 hrvoje.senjan@gmail.com
- Update to 5.3.2 final
  * No changes since previous snapshot
  * Use official tars
* Thu Sep  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.2~git20140904 (rd8bc98b):
  * Tip of the bugfix 5.3.2 branch:
  * Update copyright year in About dialogs
  * fix gaelic plural rules
  * Add bearer plugin deployment
  * qtpaths: add missing GenericConfigLocation,
    exists since Qt 5.2.0
  * Ignore local and non-filesystem qml imports.
  * Bump version
* Mon Sep  1 2014 hrvoje.senjan@gmail.com
- Drop icons from sources, and install them directly from tarball
- Add QDBusViewer desktop file
- Add trailing ';' to desktop files
* Wed Jun 25 2014 hrvoje.senjan@gmail.com
- Update to 5.3.1
  * Bugfix release, for more details please see:
    http://blog.qt.digia.com/blog/2014/06/25/qt-5-3-1-released/
* Mon Jun  2 2014 hrvoje.senjan@gmail.com
- Add baselibs.conf
- Make private headers noarch
* Mon May 19 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 final
  * Minor bugfixes over previous RC
* Thu May  8 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 RC
  * For more details, please see
  http://blog.qt.digia.com/blog/2014/05/08/qt-5-3-release-candidate-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.3
* Wed Apr 16 2014 hrvoje.senjan@gmail.com
- Split out linguist related binaries and CMake files to separate
  packages: libqt5-linguist and libqt5-linguist-devel.
* Tue Mar 25 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 beta
  * New feature release, please see
  http://blog.qt.digia.com/blog/2014/03/25/qt-5-3-beta-released/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.3
* Fri Mar 21 2014 hrvoje.senjan@gmail.com
- Build, and add examples subpackage
* Mon Feb 10 2014 mlin@suse.com
- Update LICENSE files in %%doc
* Wed Feb  5 2014 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/02/05/qt-5-2-1-released/
- Remove libtool archives from packages
* Mon Dec 16 2013 hrvoje.senjan@gmail.com
- Make devel packages naming consistent:
  use libqt5-$upstreammodulename-(devel, private-headers-devel)
* Thu Dec 12 2013 hrvoje.senjan@gmail.com
- Update to 5.2.0 final:
  * For more details please see:
    http://blog.qt.digia.com/blog/2013/12/12/qt-5-2-released-the-best-qt-yet/
    http://qt-project.org/qt5/qt52
    http://qt.digia.com/Product/Whats-New/Qt-52/
* Fri Nov 29 2013 hrvoje.senjan@gmail.com
- Update to 5.2 rc1
  * New feature release, please see
  http://blog.qt.digia.com/blog/2013/11/29/qt-5-2-release-candidate-1-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.2
* Wed Oct 23 2013 hrvoje.senjan@gmail.com
- Update to 5.2 beta1
  * New feature release, please see
  http://blog.qt.digia.com/blog/2013/10/23/qt-5-2-beta-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.2
* Thu Oct 17 2013 hrvoje.senjan@gmail.com
- Split out libqt5-tools package further to libQt5CLucene5, libQt5Designer5,
  libQt5DesignerComponents5 and libQt5Help5, main package now contains
  only binaries
- Utilize Qt5 macros
* Wed Sep 11 2013 hrvoje.senjan@gmail.com
- Remove qt5config.desktop, as the binary for it doesn't exists
* Thu Aug 29 2013 hrvoje.senjan@gmail.com
- Update to version 5.1.1:
  * Bugfix release, please see
  http://blog.qt.digia.com/blog/2013/08/28/qt-5-1-1-released/
  http://qt.gitorious.org/qt/qttools/blobs/release/dist/changes-5.1.1
  and http://qt-project.org/wiki/Qt511KnownIssues for known issues
- Small spec cleanup
* Sun Jul  7 2013 stephan.binner@basyskom.com
- update to Qt 5.1 release
* Tue Jun 18 2013 stephan.binner@basyskom.com
- update to Qt 5.1 RC 1
* Mon May 20 2013 stephan.binner@basyskom.com
- update to Qt 5.1 Beta 1
* Tue Apr  9 2013 stephan.binner@basyskom.com
- update to Qt 5.1 Alpha 1
* Wed Jan 30 2013 stephan.binner@basyskom.com
- update to Qt 5.0.1
* Wed Dec 19 2012 stephan.binner@basyskom.com
- update to Qt 5.0 release
* Thu Dec 13 2012 stephan.binner@basyskom.com
- update to Qt 5.0 Release Candidate 2
* Thu Dec  6 2012 stephan.binner@basyskom.com
- update to Qt 5.0 Release Candidate 1
* Thu Nov 15 2012 stephan.binner@basyskom.com
- update to Qt 5.0 Beta 2
* Thu Aug 30 2012 stephan.binner@basyskom.com
- update to Qt 5.0 Beta 1 release
* Thu May 24 2012 stephan.binner@basyskom.com
- update to newer Alpha snapshot / Beta candidate
* Fri Apr 13 2012 stephan.binner@basyskom.com
- rework package splitting for Qt 5 modularization
* Thu Apr  5 2012 dmueller@suse.com
- Initial packaging (Qt 5.0 Alpha)
